@@ -74,7 +74,7 @@
 #' }
 
 info <- function(datasetid, url = eurl(), ...){
-  json <- erdddap_GET(sprintf(paste0(url, 'info/%s/index.json'), datasetid), list(), ...)
+  json <- erdddap_GET(sprintf(paste0(url, 'info/%s/index.json'), datasetid), NULL, ...)
   colnames <- vapply(tolower(json$table$columnNames), function(z) gsub("\\s", "_", z), "", USE.NAMES = FALSE)
   dfs <- lapply(json$table$rows, function(x){
     tmp <- data.frame(x, stringsAsFactors = FALSE)
@@ -134,10 +134,16 @@ foo <- function(x, y){
 
 #' @export
 #' @rdname info
-as.info <- function(x) UseMethod("as.info")
+as.info <- function(x, url) {
+  UseMethod("as.info")
+}
 
 #' @export
-as.info.info <- function(x) x
+as.info.info <- function(x, url) {
+  x
+}
 
 #' @export
-as.info.character <- function(x) info(x)
+as.info.character <- function(x, url) {
+  info(x, url)
+}
